Enums
- Delete
Message Reaction Error - struct for typed errors of method
delete_message_reaction - GetClient
Reactions Error - struct for typed errors of method
get_client_reactions - Send
Message Reaction Error - struct for typed errors of method
send_message_reaction
Functions
- delete_
message_ reaction - Removes a reaction from a message. For
uniquereactions thenameis not required; fordistinctandmultiplereactions thenameis required. - get_
client_ reactions - Returns the reaction summary filtered to a single client. Useful when a message’s reaction summary is clipped (too many reacting clients) and you need to determine whether a specific client has reacted.
- send_
message_ reaction - Adds a reaction to a message. Behaviour depends on the reaction
type:unique(at most one reaction per client),distinct(at most one of each named reaction per client),multiple(repeatable, counted bycount).