pub struct MessageReactions {
pub unique: Option<HashMap<String, ClientIdList>>,
pub distinct: Option<HashMap<String, ClientIdList>>,
pub multiple: Option<HashMap<String, ClientIdCounts>>,
}Expand description
MessageReactions : Summary of reactions on a message, grouped by reaction type. Each map is keyed by the reaction name (e.g. an emoji).
Fields
unique: Option<HashMap<String, ClientIdList>>distinct: Option<HashMap<String, ClientIdList>>multiple: Option<HashMap<String, ClientIdCounts>>Implementations
Sourceimpl MessageReactions
impl MessageReactions
Sourcepub fn new() -> MessageReactions
pub fn new() -> MessageReactions
Summary of reactions on a message, grouped by reaction type. Each map is keyed by the reaction name (e.g. an emoji).